from distutils.core import setup
setup(
  name = 'filebrowser_s3',
  packages = ['filebrowser_s3'],
  version = '0.1.14',
  description = 'an S3 fix for Mezzanine\'s media manager',
  author = 'Mozilla Foundation',
  author_email = 'pomax@mozillafoundation.org',
  url = 'https://github.com/Pomax/filebrowser_s3',
  download_url = 'https://github.com/Pomax/filebrowser_s3/archive/0.1.14.tar.gz',
  keywords = ['mezzanine', 'filebrowser', 'filebrowser_safe', 'aws', 's3'],
  classifiers = [],
  include_package_data = True,
)